<?xml version="1.0" encoding="UTF-8"?>
<!--
***********************************************************
** home.xslt
**
** Transforms the home page into XHTML
***********************************************************
-->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="utils.xslt"/>
	<xsl:param name="rootDir" select="'../docroot/'"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" 
		indent="yes" 
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>
	
	<!--
	**********************************************************
	** Create the XHTML web page
	*******************************************************-->
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>Discussion Forum Home</title>
				<link href="{$rootDir}forum.css" 
						rel="stylesheet" type="text/css"/>
			</head>
			<body>
				<div class="box1">
					<h1>Discussion Forum Home</h1>
				</div>
				<xsl:apply-templates select="home/board"/>
			</body>
		</html>
	</xsl:template>
	
	<!--
	**********************************************************
	** Output a box for each board in the discussion forum
	**********************************************************
	-->
	<xsl:template match="board">
		<xsl:variable name="boardID" select="@id"/>
		
		<div class="box2">
			<h2><xsl:value-of select="name"/></h2>
			<div><xsl:value-of select="description"/></div>
			<div style="margin-left: 2em;">
				<!-- create a link so the user can post a new message
				     to this board -->
				<p>
				<a href=
	 "/forum/main/postMsg?mode=postNewMsg&amp;boardID={$boardID}">Post Message</a>
				to <xsl:value-of select="name"/>
				</p>
				
				<!-- For each month that has messages, show the 
				     month name and year number as a link -->
				<xsl:for-each select="messages">
					<a href=
	"/forum/main/viewMonth?boardID={$boardID}&amp;month={@month}&amp;year={@year}">
						<xsl:call-template name="utils.printShortMonthName">
							<xsl:with-param name="monthNumber" select="@month"/>
						</xsl:call-template>
						<xsl:text>, </xsl:text>
						<xsl:value-of select="@year"/>
					</a>
					<!-- put a pipe character after 
					     all but the last month -->
					<xsl:if test="position() != last()">
						<xsl:text> | </xsl:text>
					</xsl:if>
				</xsl:for-each>
			</div>
		</div>
	</xsl:template>
</xsl:stylesheet>
