<?xml version="1.0" encoding="UTF-8"?>
<!--
***********************************************************
** viewMonth.xslt
**
** Shows a month-view of messages in a given board.
***********************************************************
-->
<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:import href="utils.xslt"/>
	<xsl:param name="rootDir" select="'../docroot/'"/>
	<xsl:output method="xml" version="1.0" encoding="UTF-8" 
		indent="yes" 
		doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" 
		doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"/>
	<!-- ================= Global Variables ================= -->
	<xsl:variable name="global.boardName" select="/viewMonth/board/name"/>
	<xsl:variable name="global.boardID" select="/viewMonth/board/@id"/>
	<xsl:variable name="global.monthNum" select="/viewMonth/@month"/>
	<xsl:variable name="global.yearNum" select="/viewMonth/@year"/>
	
	<!--
	**********************************************************
	** Create the XHTML web page
	*******************************************************-->
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<head>
				<title>
					<xsl:value-of select="$global.boardName"/>
				</title>
				<!-- reference an external CSS file to keep this
				     XSLT stylesheet smaller -->
				<link href="{$rootDir}forum.css" 
						rel="stylesheet" type="text/css"/>
			</head>
			<body>
				<div class="box1">
					<h1>
						<xsl:value-of select="$global.boardName"/>
					</h1>
				</div>
				<div class="box2">
					<xsl:text>Messages for </xsl:text>
					<xsl:call-template name="utils.printLongMonthName">
						<xsl:with-param name="monthNumber" select="$global.monthNum"/>
					</xsl:call-template>
					<xsl:text>, </xsl:text>
					<xsl:value-of select="$global.yearNum"/>
				</div>
				<!-- ===== Quick Actions ====== -->
				<h3>Quick Actions</h3>
				<ul>
					<li>
						<a href="postMsg?mode=postNewMsg&amp;boardID={$global.boardID}">
					Post</a> a new message...</li>
					<li>Return to the <a href="home">home page</a>...</li>
				</ul>
				<!-- ===== Recursively show the message tree ===== -->
				<xsl:apply-templates select="viewMonth/message"/>
			</body>
		</html>
	</xsl:template>

	<!--
	**********************************************************
	** Display a one-line summary for each message.
	*******************************************************-->
	<xsl:template match="message">
		<xsl:param name="indent" select="0"/>
		
		<!-- indent according to the 'indent' parameter -->
		<div style="margin-left: {$indent}em;">
			<a href="viewMsg?msgID={@id}">
				<xsl:value-of select="subject"/>
			</a>
			<xsl:text> posted by </xsl:text>
			<xsl:apply-templates select="authorEmail"/>
			<xsl:text> on </xsl:text>
			<xsl:value-of select="@day"/>
			<!-- produce "&nbsp;" (a non-breaking space) -->
			<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
			<xsl:call-template name="utils.printShortMonthName">
				<xsl:with-param name="monthNumber" select="$global.monthNum"/>
			</xsl:call-template>
			<xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
			<xsl:value-of select="$global.yearNum"/>
			
			<!-- recursively select all messages that are 
					responses to this one. Increment the indentation 
					with each call -->
			<xsl:apply-templates select="message">
				<xsl:with-param name="indent" select="$indent + 1"/>
			</xsl:apply-templates>
		</div>
	</xsl:template>
	
	<!--
	**********************************************************
	** Show the author's email address.
	*******************************************************-->
	<xsl:template match="authorEmail">
		<a href="mailto:{.}">
			<xsl:value-of select="."/>
		</a>
	</xsl:template>
</xsl:stylesheet>
